@@ -1,5 +1,5 @@
 package App::ansifold;
-our $VERSION = "1.28";
+our $VERSION = "1.29";
 
 use v5.14;
 use warnings;
@@ -247,6 +247,12 @@ sub doit {
 	    $fold->configure(prefix => $prefix);
 	}
 	my @chops = $fold->text($_)->chops;
+	if (ref $app->width eq 'ARRAY') {
+	    while (my($i, $w) = each @{$app->width}) {
+		$w = 0 if not $app->padding or $w < 0;
+		$chops[$i] //= ' ' x $w;
+	    }
+	}
 	if (@index > 0) {
 	    @chops = grep { defined } @chops[@index];
 	}
